<?php
/**
 * @copyright 2018 Shift Tech Inc All Rights Reserved.
 * @author Shift Tech inc.<https://www.shift-tech.jp/>
 */
require_once (LIB_PATH.'/common/unitCommon.php');

class extAlias extends unitCommon
{
    //------ ユニット毎に必ず設定しなくてはならない変数 -------//
    var $_table = "extunit_alias";        //公開用テーブル名
    var $_tmptable = "extunit_alias_tmp";    //下書き用テーブル名
    var $columns = array(
        array("column"=>"pageu_code","conv"=>"n","tags"=>false),
        array("column"=>"pageu_code_sync","conv"=>"n","tags"=>false),
        array("column"=>"use_sp_flg","conv"=>"n","tags"=>false),
        array("column"=>"use_pc_flg","conv"=>"n","tags"=>false),
        array("column"=>"bg_color","conv"=>"n","tags"=>false),        //背景色
        array("column"=>"bdr_type","conv"=>"n","tags"=>false),        //ボーダー
        array("column"=>"btm_padding","conv"=>"n","tags"=>false),      //下方スペース
        array("column"=>"bg_color_sp","conv"=>"n","tags"=>false),     //背景色
        array("column"=>"bdr_type_sp","conv"=>"n","tags"=>false),    //ボーダー
        array("column"=>"btm_padding_sp","conv"=>"n","tags"=>false),   //下方スペース
        array("column"=>"extra_class", "conv" => "as", "tags" => false),  //追加クラス
        array("column"=>"option_extend", "conv" => "n", "tags" => false),  //デザインオプションの継承
        array("column"=>"anchor_text", "conv" => "KVa", "tags" => false),  //デザインオプションの継承
    );

    function __construct()
    {
        unitCommon::__construct();
    }

    //出力データセット処理（必須）
    function setDisplayData() {
        $this->_data = $this->getDetail();
        if(!empty($this->_data)) {
            $codeError = false;
            if(isset($this->_data['pageu_code_sync']) && is_numeric($this->_data['pageu_code_sync'])) {
                $code = $this->_data['pageu_code_sync'];
                //ユニットの存在検証
                $unit = null;
                $tmp = $this->_prev ? "_tmp": "";
                $result = $this->db->prepare('SELECT * FROM tbl_page_unit'.$tmp.'
                    JOIN tbl_unit ON unit_code = pageu_unit_code
                    LEFT JOIN tbl_extmodule ON extmodule_code = unit_extmodule_code
                    WHERE pageu_code = ? AND unit_active = 1', array($code));
                if($result) {
                    $unit = $result->fetchRow(DB_FETCHMODE_ASSOC);
                }
                if(!is_null($unit)) {
                    //存在していれば追っていく
                    return $this->cloneUnit($unit);
                } else {
                    if(!isset($this->_view->_tpl_vars['adminView'])) {
                        $this->_data['use_pc_flg'] = 0;
                        $this->_data['use_sp_flg'] = 0;
                    }
                    $this->unittplpath = __DIR__;
                }
            } else {
                return null;
            }

            $this->_view->assign('codeError', $codeError);
        }

        return $this->_data;
    }

    /**
     * HTMLコード動的出力（必須）（共通）.
     *
     * pageunitDBから呼ばれる
     *
     * @param int $unit_type ユニットタイプ
     *
     * @return string|null HTMLコード
     */
    public function setDisplayDataWithBox($unit_type = null)
    {
        $data = $this->setDisplayData();
        if ($data != null) {
            //スマートフォンでアクセス時
            $_pc_display_none_msg = '';
            if ($this->_view->_tpl_vars['adminView'] != 1) {
                if (Model::checkSP()) {
                    //スマホ表示フラグ=0の時は何も表示しない。
                    if (isset($data['use_sp_flg']) && $data['use_sp_flg'] != 1) {
                        return '';
                    }
                    //ローカルメニューユニットは表示させない
                    if (!$this->_sidesetting && $this->_dir == '/bCategory') {
                        return '';
                    }
                }
                //PCで接続時
                else {
                    //PC表示フラグ=0の時は何も表示しない。
                    if (isset($data['use_pc_flg']) && $data['use_pc_flg'] != 1) {
                        return '';
                    }
                }
            } else {
                //管理画面の時
                $viewmode = isset($_REQUEST['viewmode']) ? $_REQUEST['viewmode'] : 'both';
                if ($viewmode == 'both') {
                    if(strpos($_SERVER['SCRIPT_NAME'], 'layout-in.php') === false && strpos($_SERVER['SCRIPT_NAME'], 'page-layout.php') === false && strpos($_SERVER['SCRIPT_NAME'], 'unitlayout-in.php') === false && strpos($_SERVER['SCRIPT_NAME'], 'page-unitlayout.php') === false &&
                        strpos($_SERVER['SCRIPT_NAME'], 'get-unithtml.php') === false ) {
                        if (defined('SP_FLG') && SP_FLG == SP_FLG_CODE) {
                            //スマホ表示フラグ=0の時は何も表示しない。
                            if (isset($data['use_sp_flg']) && $data['use_sp_flg'] != 1) {
                                return '';
                            }
                            //ローカルメニューユニットは表示させない
                            if (!$this->_sidesetting && $this->_dir == '/bCategory') {
                                return '';
                            }
                        }
                        //PCで接続時
                        else {
                            //PC表示フラグ=0の時は何も表示しない。
                            if (isset($data['use_pc_flg']) && $data['use_pc_flg'] != 1) {
                                return '';
                                exit;
                            }
                        }
                    }
                } elseif ($viewmode == 'pc') {
                    //PC用のみ表示
                    if (isset($data['use_pc_flg']) && $data['use_pc_flg'] != 1) {
                        return '';
                    }
                } elseif ($viewmode == 'sp') {
                    //スマホ用のみ表示
                    if (isset($data['use_sp_flg']) && $data['use_sp_flg'] != 1) {
                        return '';
                    }
                }
            }
            $this->_view->assign('data', $data);
            $classname = $this->getCommonUnitDecorationClassNames($data, (!isset($data['prop_use']) || $data['prop_use'] != 1));
            if ($classname != null) {
                return '<div id="unit-'.$data['pageu_code'].'" class="'.$classname.'">'.$_pc_display_none_msg.$this->_view->fetch($this->unittplpath.$this->_dir.'.tpl').'</div>';
            } else {
                return '<div id="unit-'.$data['pageu_code'].'">'.$_pc_display_none_msg.$this->_view->fetch($this->unittplpath.$this->_dir.'.tpl')."</div>\n";
            }
        } else {
            return '<div id="unit-'.$this->_pageu_code.'" class="'.$this->_unit_decoration['btm_padding'][2].'">'.$this->_view->fetch(__DIR__.'/dummy.tpl')."</div>\n";
        }
    }

    function cloneUnit($unit)
    {
        $type = $unit['unit_type'];
        $unitName = str_replace('.tpl', '', $unit['unit_tpl_path']);

        $paths = array(
            2 => BASE_PATH.'/usr-data/units/'.$unitName,
            3 => BASE_PATH.'/usr-data/units/'.$unitName,
            4 => BASE_PATH.'/usr-data/extunits/'.$unitName,
            5 => BASE_PATH.'/usr-data/extunits/'.$unitName,
            6 => BASE_PATH.'/usr-data/modules/'.$unit['extmodule_path'].'/units/'.$unitName,
            7 => BASE_PATH.'/usr-data/units/'.$unitName,
            100 => BASE_PATH.'/usr-data/units/'.$unitName,
        );
        $path = $paths[$type];

        if(!class_exists($unitName)) {
            include_once($path.'/'.$unit['unit_php_path']);
        }

        $origin = new $unitName();
        $origin->init($this->_data['pageu_code_sync'], $unitName, $this->_view, $this->_prev, $unit);
        foreach($origin as $k => $v) {
            $this->$k = $v;
        }
        $this->unittplpath = $path;

        $data = $origin->setDisplayData();

        if($origin instanceof extAlias) {
            $this->unittplpath = $origin->unittplpath;
            $this->_dir = $origin->_dir;
        }

        return $data;
    }

    /*
     * DBより保存データ取得
     * 改変可能
     */
    function getDetail() {
        $rtn =  null;
        $sql = "select * from ".$this->getTbl()." where pageu_code = ?";
        if(isset($this->_pageu_code)&&is_numeric($this->_pageu_code)) {
            $result = $this->db->prepare($sql,$this->_pageu_code);
            if($result){
                $rtn = $result->fetchRow(DB_FETCHMODE_ASSOC);
            }
        }
        return $rtn;
    }


    function setDefault()
    {
        $data = $this->getDetail();
        if ($data) {
            $this->_form->setDefaults($data);

            $code = $data['pageu_code_sync'];
            //ユニットの存在検証
            $unit = null;
            $result = $this->db->prepare('SELECT * FROM tbl_page_unit_tmp
                JOIN tbl_unit ON unit_code = pageu_unit_code
                LEFT JOIN tbl_extmodule ON extmodule_code = unit_extmodule_code
                WHERE pageu_code = ? AND unit_active = 1', array($code));
            if($result) {
                $unit = $result->fetchRow(DB_FETCHMODE_ASSOC);
            }
            if(!is_null($unit)) {
                //存在していれば追っていく
                $this->_view->assign('data', $data);
            }
        } else {
            $data['unit_sync'] = 1;
        }
        $this->_form->setDefaults($data);
    }

    /**
     * フォームエレメントの作成.
     */
    public function setElements()
    {
        $this->_form->addElement('hidden', 'pageu_code', $this->_pageu_code, array('id' => 'pageu_code'));
        $this->_form->addElement('text', 'pageu_code_sync', null, array('id' => 'pageu_code_sync', 'style' => 'width: 10em'));
        //アンカー用テキスト
        $this->_form->addElement('text', 'anchor_text', null, array('id' => 'anchor_text', 'class' => 'txt'));
        $this->_form->addGroup(array(
            $this->_form->createElement('radio', null, null, _gettext('しない'), 1, array('labelClass'=>'radioBtn')),
            $this->_form->createElement('radio', null, null, _gettext('する'), 0, array('labelClass'=>'radioBtn')),
        ), 'unit_sync', '', '');
    }
    /**
     * フォーム入力エラーチェックの設定.
     */
    public function setRules()
    {
        $this->_form->applyFilter('__ALL__', 'trim');
        $this->_form->_submitValues = DataBase::ConvColumnVals($this->_form->_submitValues, $this->columns); //ルールに従った値変換、タグの除去
        $this->_form->setJsWarnings(_gettext('B_P00472'), '');

        $this->_form->registerRule('check_code', 'callback', array($this, 'check_code'));

        $this->_form->addRule('pageu_code', _gettext('B_P00643'), 'required', null, $this->erchk);
        $this->_form->addRule('pageu_code_sync', _gettext('・参照ユニットコードを入力してください'), 'required', null, $this->erchk);
        $this->_form->addRule('pageu_code_sync', _gettext('・自分を設定をすることは出来ません'), 'check_code', null, $this->erchk);
    }

    public function check_code($val)
    {
        $code = str_replace("#unit-", "", $val);
        if($this->_pageu_code == $code) {
            //自己参照はさせない
            return false;
        }

        return true;
    }

    /**
     * データ下書き保存処理.
     *
     * @param array $post 保存データ
     *
     * @return null|string エラー時=string
     */
    public function doSave($post)
    {
        $old_data = $this->getDetail();
        $record = null;
        foreach ($this->columns as $val) {
            if ($post[$val['column']] != null) {
                $record[$val['column']] = $post[$val['column']];
            } else {
                $record[$val['column']] = null;
            }
        }
        $record['use_pc_flg'] = 1;
        $record['use_sp_flg'] = 1;
        $record['pageu_code_sync'] = str_replace("#unit-", "", $record['pageu_code_sync']);

        $this->db->query('BEGIN');
        //保存処理開始
        if (is_array($old_data) && count($old_data) > 0) {
            //更新
            if (!$this->db->update($this->getTbl(), $record, 'pageu_code='.$record['pageu_code'])) {
                $this->db->query('ROLLBACK');

                return _gettext('B_P00209');
            }
        } else { //新規
            if (!$this->db->insert($this->getTbl(), $record)) {
                $this->db->query('ROLLBACK');

                return _gettext('B_P00209');
            }
        }

        if (!bUtil::deleteLink('ul_pageu_code='.$this->_pageu_code) || !bUtil::setLink($this->_pageu_code, $record['pageu_code_sync'], 1)) {
            $this->db->query('ROLLBACK');

            return _gettext('B_P00209');
        }

        $this->db->query('COMMIT');

        return;
    }
}
